@@ -3,10 +3,10 @@ from wpilib import ADIS16448_IMU
 
 from robotpy_toolkit_7407.utils.units import radians
 
-from robotpy_toolkit_7407.sensors.gyro.base_gyro import Gyro
+from robotpy_toolkit_7407.sensors.gyro.base_gyro import BaseGyro
 
 
-class GyroADIS16448(Gyro):
+class GyroADIS16448(BaseGyro):
     """
     Wrapper class for the ADIS16448 Gyro
     """
@@ -28,8 +28,8 @@ class GyroADIS16448(Gyro):
         """
         return math.radians(self._gyro.getGyroAngleZ() + self.__offset)
 
-    def reset_angle(self):
+    def reset_angle(self, angle: radians = 0):
         """
         Resets the gyro's yaw.
         """
-        self.__offset = self.get_robot_heading()
+        self.__offset = self.get_robot_heading() - angle
